TreemapTile class

Contains information about the treemap tile.

Properties

color → Color
Color of the tile.
no setter
group → String
Name of the tile group. This is the value returned in the TreemapLevel.groupMapper.
no setter
hasDescendants → bool
Specifies whether this tile has any descendant tiles.
no setter
hashCode → int
The hash code for this object.
no setterinherited
indices → List<int>
Contains the indices of the data source which forms this tile.
no setter
level → TreemapLevel
Respected tile level details.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight → double
Weight of the respected tile.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited